@@ -1,5 +1,5 @@
 ﻿/*
-   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,11 +24,7 @@
 
 #include <AkonadiCore/CollectionModifyJob>
 #include <AkonadiCore/CollectionFilterProxyModel>
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-#include <KRecursiveFilterProxyModel>
-#else
 #include <QSortFilterProxyModel>
-#endif
 #include <QInputDialog>
 
 #include <AkonadiWidgets/CollectionRequester>
@@ -110,7 +106,7 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     : QWidget(parent)
 {
     QHBoxLayout *mainLayout = new QHBoxLayout(this);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
 
     QTabWidget *tabWidget = new QTabWidget;
     mainLayout->addWidget(tabWidget);
@@ -144,12 +140,8 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
 
     connect(mModel, &Akonadi::EntityTreeModel::collectionTreeFetched, this, &KNoteCollectionConfigWidget::slotCollectionsInserted);
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    mCollectionFilter = new KRecursiveFilterProxyModel(this);
-#else
     mCollectionFilter = new QSortFilterProxyModel(this);
     mCollectionFilter->setRecursiveFilteringEnabled(true);
-#endif
     mCollectionFilter->setSourceModel(mDisplayNotifierProxyModel);
     mCollectionFilter->setDynamicSortFilter(true);
     mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
